@@ -1,11 +1,11 @@
 #
 # This file is part of Orchid and related technologies.
 #
-# Copyright (c) 2017-2023 Reveal Energy Services.  All Rights Reserved.
+# Copyright (c) 2017-2024 KAPPA.  All Rights Reserved.
 #
 # LEGAL NOTICE:
 # Orchid contains trade secrets and otherwise confidential information
-# owned by Reveal Energy Services. Access to and use of this information is 
+# owned by KAPPA. Access to and use of this information is
 # strictly limited and controlled by the Company. This file may not be copied,
 # distributed, or otherwise disclosed outside of the Company's facilities 
 # except under appropriate precautions to maintain the confidentiality hereof, 
@@ -34,6 +34,9 @@ from orchid import (
     net_fracture_diagnostics_factory as net_factory,
 )
 
+from pythonnet import load
+load('coreclr')
+
 # noinspection PyUnresolvedReferences,PyPackageRequirements
 import clr
 
@@ -217,7 +220,7 @@ demo_1h = candidate_wells[0]
 
 # Create an attribute with name, 'My New Attribute', and type, `System.Int32`
 attribute_to_add_type = Int32
-attribute_to_add = object_factory.CreateAttribute[attribute_to_add_type]('My New Attribute')
+attribute_to_add = object_factory.CreateAttribute[attribute_to_add_type]('My New Attribute', -1)
 
 # Add newly created attribute to well, 'Demo_1H'
 with orchid.dot_net_disposable.disposable(demo_1h.dom_object.ToMutable()) as mutable_well:
